@@ -39,6 +39,8 @@
 #define CODEC_AVC_MIN_QP_LP 10
 #define CODEC_AVC_MIN_QP1 1
 #define CODEC_AVC_MIN_QP5 5
+// Minimum QP value for base/default platforms
+#define CODEC_AVC_MIN_QP10 10
 
 #define CODEC_AVC_NUM_WP_FRAME              8
 #define CODEC_AVC_MAX_FORWARD_WP_FRAME      6
