@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2015-2021, Intel Corporation
+* Copyright (c) 2015-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -50,6 +50,10 @@ class MhwCpInterface;
 #define MHW_MI_DECODER_AV1_WATCHDOG_THRESHOLD_IN_MS     80
 #define MHW_MI_DECODER_16K_WATCHDOG_THRESHOLD_IN_MS     180
 #define MHW_MI_DECODER_16Kx16K_WATCHDOG_THRESHOLD_IN_MS 256
+#define MHW_MI_DECODER_FHD_WATCHDOG_THRESHOLD_IN_MS_PLUS 30
+#define MHW_MI_DECODER_4K_WATCHDOG_THRESHOLD_IN_MS_PLUS  60
+#define MHW_MI_DECODER_8K_WATCHDOG_THRESHOLD_IN_MS_PLUS  120
+#define MHW_MI_DECODER_16K_WATCHDOG_THRESHOLD_IN_MS_PLUS 200
 #define MHW_MI_WATCHDOG_COUNTS_PER_MILLISECOND         (19200123 / 1000)   // Time stamp counts per millisecond
 
 typedef enum _MHW_COMMON_MI_ADDRESS_SHIFT
@@ -64,9 +68,9 @@ typedef enum _MHW_COMMON_MI_ADDRESS_SHIFT
 
 typedef enum _MHW_MI_SET_PREDICATE_ENABLE
 {
-    MHW_MI_SET_PREDICATE_DISABLE   = 0x0,
-    MHW_MI_SET_PREDICATE_ENABLE_ON_CLEAR,
-    MHW_MI_SET_PREDICATE_ENABLE_ON_SET,
+    MHW_MI_SET_PREDICATE_DISABLE   = 0x0, // Predication is Disabled and CS will process commands as usual.
+    MHW_MI_SET_PREDICATE_ENABLE_ON_CLEAR, // Following Commands will be NOOPED by CS only if the MI_PREDICATE_RESULT_2 is clear.
+    MHW_MI_SET_PREDICATE_ENABLE_ON_SET,   // Following Commands will be NOOPED by CS only if the MI_PREDICATE_RESULT_2 is set.
     MHW_MI_SET_PREDICATE_ENABLE_ALWAYS = 0xF,
 } MHW_MI_SET_PREDICATE_ENABLE;
 
@@ -281,11 +285,13 @@ typedef struct _MHW_MI_ATOMIC_PARAMS
 typedef struct _MHW_MI_SEMAPHORE_WAIT_PARAMS
 {
     PMOS_RESOURCE               presSemaphoreMem;        // Semaphore memory Resource
+    uint64_t                    gpuVirtualAddress;       // Semaphore memory Resource
     uint32_t                    dwResourceOffset;
     bool                        bRegisterPollMode;
     bool                        bPollingWaitMode;
     uint32_t                    dwCompareOperation;
     uint32_t                    dwSemaphoreData;
+    bool                        b64bComparEnableWithGPR;
     MHW_COMMON_MI_SEMAPHORE_COMPARE_OPERATION       CompareOperation;
 }MHW_MI_SEMAPHORE_WAIT_PARAMS, *PMHW_MI_SEMAPHORE_WAIT_PARAMS;
 
