@@ -171,13 +171,13 @@ VAStatus DdiDecodeVP8::ParsePicParams(
         goldenRefSurface = DdiMedia_GetSurfaceFromVASurfaceID(mediaCtx, picParam->golden_ref_frame);
         if(goldenRefSurface)
         {
-            DdiMedia_MediaSurfaceToMosResource(lastRefSurface, &m_resNoneRegGoldenRefFrame);
+            DdiMedia_MediaSurfaceToMosResource(goldenRefSurface, &m_resNoneRegGoldenRefFrame);
             m_ddiDecodeCtx->DecodeParams.m_presNoneRegGoldenRefFrame = &m_resNoneRegGoldenRefFrame;
         }
         altRefSurface    = DdiMedia_GetSurfaceFromVASurfaceID(mediaCtx, picParam->alt_ref_frame);
         if(altRefSurface)
         {
-            DdiMedia_MediaSurfaceToMosResource(lastRefSurface, &m_resNoneRegAltRefFrame);
+            DdiMedia_MediaSurfaceToMosResource(altRefSurface, &m_resNoneRegAltRefFrame);
             m_ddiDecodeCtx->DecodeParams.m_presNoneRegAltRefFrame = &m_resNoneRegAltRefFrame;
         }
     }
@@ -235,20 +235,17 @@ VAStatus DdiDecodeVP8::ParsePicParams(
     codecPicParams->ucUvModeProbs[0]            = picParam->uv_mode_probs[0];
     codecPicParams->ucUvModeProbs[1]            = picParam->uv_mode_probs[1];
     codecPicParams->ucUvModeProbs[2]            = picParam->uv_mode_probs[2];
-    if (codecPicParams->ucMvUpdateProb[0] && picParam->mv_probs[0])
-    {
-        MOS_SecureMemcpy(codecPicParams->ucMvUpdateProb[0],
-            sizeof(codecPicParams->ucMvUpdateProb[0]),
-            picParam->mv_probs[0],
-            sizeof(codecPicParams->ucMvUpdateProb[0]));
-    }
-    if (codecPicParams->ucMvUpdateProb[1] && picParam->mv_probs[1])
-    {
-        MOS_SecureMemcpy(codecPicParams->ucMvUpdateProb[1],
-            sizeof(codecPicParams->ucMvUpdateProb[1]),
-            picParam->mv_probs[1],
-            sizeof(codecPicParams->ucMvUpdateProb[1]));
-    }
+
+    MOS_SecureMemcpy(codecPicParams->ucMvUpdateProb[0],
+        sizeof(codecPicParams->ucMvUpdateProb[0]),
+        picParam->mv_probs[0],
+        sizeof(codecPicParams->ucMvUpdateProb[0]));
+
+    MOS_SecureMemcpy(codecPicParams->ucMvUpdateProb[1],
+        sizeof(codecPicParams->ucMvUpdateProb[1]),
+        picParam->mv_probs[1],
+        sizeof(codecPicParams->ucMvUpdateProb[1]));
+
     codecPicParams->ucP0EntropyCount = (8 - picParam->bool_coder_ctx.count) & 0x7;  //hardware needs used bits not remaining bits in bool decoder
     codecPicParams->ucP0EntropyValue = picParam->bool_coder_ctx.value;
     codecPicParams->uiP0EntropyRange = picParam->bool_coder_ctx.range;
@@ -264,21 +261,12 @@ VAStatus DdiDecodeVP8::ParseProbabilityData(
 {
     if (vp8ProbDataBuff->pData && probInputBuf)
     {
-        MOS_LINUX_BO *boDes = nullptr;
-        boDes               = vp8ProbDataBuff->bo;
-
-        mos_bo_wait_rendering(boDes);
-        if (0 == mos_bo_subdata(boDes,
-                     0,
-                     sizeof(CODECHAL_VP8_COEFFPROB_DATA),
-                     probInputBuf))
-        {
-            return VA_STATUS_SUCCESS;
-        }
-        else
-        {
-            return VA_STATUS_ERROR_INVALID_PARAMETER;
-        }
+        mos_bo_wait_rendering(vp8ProbDataBuff->bo);
+        MOS_SecureMemcpy(vp8ProbDataBuff->pData,
+                         sizeof(CODECHAL_VP8_COEFFPROB_DATA),
+                         probInputBuf,
+                         sizeof(CODECHAL_VP8_COEFFPROB_DATA));
+        return VA_STATUS_SUCCESS;
     }
     else
     {
