@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020-2021, Intel Corporation
+* Copyright (c) 2020-2025, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -46,7 +46,7 @@ MOS_STATUS DecodeSfcHistogramSubPipeline::Init(CodechalSetting &settings)
     DECODE_FUNC_CALL();
     DECODE_CHK_NULL(m_pipeline);
 
-    CodechalHwInterface* hwInterface = m_pipeline->GetHwInterface();
+    CodechalHwInterfaceNext *hwInterface = m_pipeline->GetHwInterface();
     DECODE_CHK_NULL(hwInterface);
     m_osInterface = hwInterface->GetOsInterface();
     DECODE_CHK_NULL(m_osInterface);
@@ -84,20 +84,46 @@ MOS_STATUS DecodeSfcHistogramSubPipeline::Prepare(DecodePipelineParams &params)
         DECODE_CHK_STATUS(Begin());
     }
     else if (params.m_pipeMode == decodePipeModeProcess &&
-             m_downsampFeature != nullptr && m_downsampFeature->m_histogramBuffer != nullptr)  //m_downsampFeature could be null if downsampling is not enabled
+             m_downsampFeature != nullptr && m_downsampFeature->IsEnabled())  //m_downsampFeature could be null if downsampling is not enabled
     {
         DECODE_CHK_NULL(params.m_params);
         DECODE_CHK_NULL(m_basicFeature);
-        DECODE_CHK_NULL(m_downsampFeature->m_histogramBuffer);
+        CodechalDecodeParams *decodeParams = params.m_params;
 
-        CodechalDecodeParams*   decodeParams    = params.m_params;
-        PMOS_RESOURCE           src             = &m_downsampFeature->m_histogramBuffer->OsResource;
-        PMOS_RESOURCE           dest            = &decodeParams->m_histogramSurface.OsResource;
-        uint32_t                destOffset      = decodeParams->m_histogramSurface.dwOffset;
-        if (!m_allocator->ResourceIsNull(src) &&
-            !m_allocator->ResourceIsNull(dest))
+        if (m_downsampFeature->m_histogramBuffer)
         {
-            DECODE_CHK_STATUS(CopyHistogramToDestBuf(src, dest, destOffset));
+            PMOS_RESOURCE         src          = &m_downsampFeature->m_histogramBuffer->OsResource;
+            PMOS_RESOURCE         dest         = &decodeParams->m_histogramSurface.OsResource;
+            uint32_t              destOffset   = decodeParams->m_histogramSurface.dwOffset;
+            if (!m_allocator->ResourceIsNull(src) &&
+                !m_allocator->ResourceIsNull(dest))
+            {
+                DECODE_CHK_STATUS(CopyHistogramToDestBuf(src, dest, destOffset));
+            }
+        }
+
+        if (m_downsampFeature->m_histogramBufferU)
+        {
+            PMOS_RESOURCE srcU        = &m_downsampFeature->m_histogramBufferU->OsResource;
+            PMOS_RESOURCE destU       = &decodeParams->m_histogramSurfaceU.OsResource;
+            uint32_t      destOffsetU = decodeParams->m_histogramSurfaceU.dwOffset;
+            if (!m_allocator->ResourceIsNull(srcU) &&
+                !m_allocator->ResourceIsNull(destU))
+            {
+                DECODE_CHK_STATUS(CopyHistogramToDestBuf(srcU, destU, destOffsetU));
+            }
+        }
+
+        if (m_downsampFeature->m_histogramBufferV)
+        {
+            PMOS_RESOURCE srcV        = &m_downsampFeature->m_histogramBufferV->OsResource;
+            PMOS_RESOURCE destV       = &decodeParams->m_histogramSurfaceV.OsResource;
+            uint32_t      destOffsetV = decodeParams->m_histogramSurfaceV.dwOffset;
+            if (!m_allocator->ResourceIsNull(srcV) &&
+                !m_allocator->ResourceIsNull(destV))
+            {
+                DECODE_CHK_STATUS(CopyHistogramToDestBuf(srcV, destV, destOffsetV));
+            }
         }
     }
 
