@@ -37,6 +37,7 @@ namespace encode
 #define AV1_ENCODE_GET_REF_FALG(i) (0x1 << i)
 
 class Av1BasicFeature;
+class Av1VdencPipeline;
 
 class Av1ReferenceFrames : public mhw::vdbox::vdenc::Itf::ParSetting, public mhw::vdbox::avp::Itf::ParSetting
 {
@@ -160,6 +161,12 @@ public:
     //!
     void GetFwdBwdRefPicList(CODEC_PICTURE (&refsPicList)[2][15]);
 
+    //! \brief  Get  get current frame display order
+    //! \return int32_t
+    //!         frame display order
+    //!
+    int32_t GetFrameDisplayOrder();
+
     //!
     //! \brief  Get  get the Picture Order Count values of reference pictures 
     //!          corresponding to the entries of RefFrameList[]. 
@@ -173,6 +180,13 @@ public:
     bool CheckSegmentForPrimeFrame();
     uint8_t RefFrameL0L1(CODEC_Ref_Frame_Ctrl_AV1 const &ref_frame_ctrl) const;
 
+     //!
+    //! \brief  Dump input resources or infomation before submit
+    //! \return MOS_STATUS
+    //!         MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    MOS_STATUS DumpInput(Av1VdencPipeline *pipeline);
+
     MHW_SETPAR_DECL_HDR(VDENC_PIPE_BUF_ADDR_STATE);
 
     MHW_SETPAR_DECL_HDR(VDENC_CMD2);
@@ -185,6 +199,8 @@ public:
 
     MHW_SETPAR_DECL_HDR(AVP_SURFACE_STATE);
 
+    bool m_lowDelay = true;//!< Low delay flag
+
 protected:
     static const uint32_t      m_av1ScalingFactor       = (1 << 14);    //!< AV1 Scaling factor
     //!
@@ -224,6 +240,45 @@ protected:
 
     int32_t GetRelativeDist(int32_t a, int32_t b) const;
 
+    // Common POC Handling Functions
+    //!
+    //! \brief  Populate reference frame POC values and calculate savedOrderHints
+    //! \details This function populates reference frame POCs and calculates 
+    //!          savedOrderHints[7][7] internally, storing results in m_savedOrderHints
+    //!          member variable for motion field projection.
+    //! \param  [out] refsPOCList
+    //!         Array to store POC values for all reference frames
+    //! \return void
+    //!
+    void PopulateReferenceFramePOCs(int32_t (&refsPOCList)[7]);
+
+    // Motion Field Projection Logic
+    //!
+    //! \brief  Calculate active reference bitmask for motion field projection
+    //! \return uint8_t
+    //!         Bitmask indicating which references are active (max 3 bits set)
+    //!
+    uint8_t CalculateActiveRefBitmask();
+
+    //!
+    //! \brief  Validate if reference frame is suitable for motion field projection
+    //! \param  [in] refIdx
+    //!         Reference frame index
+    //! \param  [in] refOrderHint
+    //!         Order hint of the reference frame
+    //! \return bool
+    //!         true if reference is valid for motion field projection
+    //!
+    bool ValidateMotionFieldReference(uint8_t refIdx, uint8_t refOrderHint);
+
+    // Collocated MV Buffer Management
+    //!
+    //! \brief  Get current frame's collocated MV buffer for AVP output
+    //! \return PMOS_RESOURCE
+    //!         Pointer to current frame's colMV buffer
+    //!
+    PMOS_RESOURCE GetCurrentColMVBuffer();
+
     //!
     //! \brief  Get FWD and BWD reference number
     //! \return MOS_STATUS
@@ -251,10 +306,13 @@ protected:
     MOS_MEMCOMP_STATE       m_refMmcState[av1TotalRefsPerFrame] = { MOS_MEMCOMP_DISABLED };
     uint32_t                m_refCompressionFormat = 0;
     CODEC_PIC_ID            m_picIdx[CODEC_AV1_NUM_REF_FRAMES] = {}; //!< keep a map of frame index
-    bool                    m_lowDelay = true;                       //!< Low delay flag
     bool                    m_PFrame   = true;                       //!< P frame flag
     bool                    m_enable_order_hint = false;
     uint8_t                 m_orderHintBitsMinus1 = 0;
+    uint8_t                 m_orderHintCount[ENCODE_AV1_ORDER_HINT_SIZE];
+    int32_t                 m_frameOut = 0;                        //!<frame output number
+    int32_t                 m_prevFrameOffset = 0;
+    int32_t                 m_prevFrameDisplayerOrder = 0;
 
     bool       m_encUsePostCdefAsRef = false;
     BufferType m_encRefBufType       = BufferType::postCdefReconSurface;
@@ -263,6 +321,10 @@ protected:
     uint32_t   m_refWidth            = 0;
     uint32_t   m_refHeight           = 0;
 
+    // Temporal MV member variables
+    uint8_t    m_activeRefBitmaskMfProj = 0;  //!< Active reference bitmask for motion field projection
+    uint8_t    m_savedOrderHints[7][7] = {};  //!< Saved order hints for reference-of-reference frames [ref][ref_of_ref]
+
     union
     {
         struct
