@@ -30,7 +30,8 @@
 #define __MEDIA_ENCODE_MEM_COMPRESSION_H__
 
 #include "media_mem_compression.h"
-#include "codechal_hw.h"
+#include "codec_hw_next.h"
+#include "mhw_mi_itf.h"
 
 class EncodeMemComp : public MediaMemComp
 {
@@ -38,7 +39,7 @@ public:
     //!
     //! \brief    Construct
     //!
-    EncodeMemComp(CodechalHwInterface *hwInterface);
+    EncodeMemComp(CodechalHwInterfaceNext *hwInterface);
 
     //!
     //! \brief    Copy constructor
@@ -64,9 +65,11 @@ protected:
     bool                    m_userFeatureUpdated = false; //!< Inidate if mmc user feature key for recon is updated
 #endif
 
-    void InitEncodeMmc(CodechalHwInterface *hwInterface);
+    void InitEncodeMmc(CodechalHwInterfaceNext *hwInterface);
 
     bool m_mmcEnabledForEncode = false;                  //!< Indicate if mmc is enabled for encode
+    
+    std::shared_ptr<mhw::mi::Itf> m_miItf;               //!< Point to MI interface
 
 MEDIA_CLASS_DEFINE_END(EncodeMemComp)
 };
