@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2021-2023, Intel Corporation
+* Copyright (c) 2021-2025, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -46,6 +46,9 @@
 #define CODEC_HW_ASSERTMESSAGE(_message, ...)                                           \
     MOS_ASSERTMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_HW, _message, ##__VA_ARGS__)
 
+#define CODEC_HW_WARNINGMESSAGE(_message, ...)                                          \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_HW, _message, ##__VA_ARGS__)
+
 #define CODEC_HW_NORMALMESSAGE(_message, ...)                                           \
     MOS_NORMALMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_HW, _message, ##__VA_ARGS__)
 
@@ -291,6 +294,17 @@ public:
         return m_vvcpItf;
     }
 
+    //!
+    //! \brief    Get aqm interface
+    //! \details  Get aqm interface in codechal hw interface next
+    //!
+    //! \return    pointer to new aqm interface
+    //!
+    inline std::shared_ptr<mhw::vdbox::aqm::Itf> GetAqmInterfaceNext()
+    {
+        return m_aqmItf;
+    }
+
     //!
     //! \brief    Get Os interface
     //! \details  Get Os interface in codechal hw interface
@@ -350,6 +364,16 @@ public:
     MOS_STATUS InitCacheabilityControlSettings(
         CODECHAL_FUNCTION codecFunction);
 
+
+    //!
+    //! \brief    Init MemoryObject Cache Settings
+    //! \details  Init MemoryObject Cache Settings in codechal hw interface
+    //!
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    MOS_STATUS InitMemoryObjectCacheSettings();
+
     //!
     //! \brief    Get memory object of GMM Cacheability control settings
     //! \details  Internal function to get memory object of GMM Cacheability control settings
@@ -817,14 +841,37 @@ public:
         MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
         CODEC_HW_CHK_NULL_RETURN(m_miItf);
-        auto &params            = m_miItf->MHW_GETPAR_F(MI_SEMAPHORE_WAIT)();
-        params                  = {};
-        params.presSemaphoreMem = semaMem;
-        params.bPollingWaitMode = true;
-        params.dwSemaphoreData  = semaData;
-        params.CompareOperation = (mhw::mi::MHW_COMMON_MI_SEMAPHORE_COMPARE_OPERATION) opCode;
-        params.dwResourceOffset = semaMemOffset;
-        eStatus                 = m_miItf->MHW_ADDCMD_F(MI_SEMAPHORE_WAIT)(cmdBuffer);
+
+        // Check if 64-bit hardware semaphore is supported
+        bool isSemaphore64Supported = MEDIA_IS_SKU(m_osInterface->pfnGetSkuTable(m_osInterface), FtrHwSemaphore64);
+
+#ifdef _MEDIA_RESERVED
+        if (isSemaphore64Supported)
+        {
+            // Use MI_SEMAPHORE_WAIT_64 for 64-bit semaphore support
+            auto &params = m_miItf->MHW_GETPAR_F(MI_SEMAPHORE_WAIT_64)();
+            params = {};
+            
+            // Initialize parameters using helper macro
+            // This macro hardcodes semaphoreToken to 0 and sets other parameters
+            INIT_MHW_MI_SEMAPHORE_WAIT_64_PARAMS(params, semaMem, semaData, opCode, semaMemOffset);
+            
+            eStatus = m_miItf->MHW_ADDCMD_F(MI_SEMAPHORE_WAIT_64)(cmdBuffer);
+        }
+        else
+#endif
+        {
+            // Fallback to MI_SEMAPHORE_WAIT for platforms without 64-bit support
+            // or when _MEDIA_RESERVED is not defined
+            auto &params            = m_miItf->MHW_GETPAR_F(MI_SEMAPHORE_WAIT)();
+            params                  = {};
+            params.presSemaphoreMem = semaMem;
+            params.bPollingWaitMode = true;
+            params.dwSemaphoreData  = semaData;
+            params.CompareOperation = (mhw::mi::MHW_COMMON_MI_SEMAPHORE_COMPARE_OPERATION) opCode;
+            params.dwResourceOffset = semaMemOffset;
+            eStatus                 = m_miItf->MHW_ADDCMD_F(MI_SEMAPHORE_WAIT)(cmdBuffer);
+        }
 
         return eStatus;
     }
@@ -1001,6 +1048,7 @@ protected:
     std::shared_ptr<mhw::render::Itf>        m_renderItf   = nullptr;      //!< Pointer to render interface
     std::shared_ptr<MediaSfcInterface>       m_mediaSfcItf = nullptr;      //!< Pointer to Media sfc interface
     std::shared_ptr<mhw::vdbox::vvcp::Itf>   m_vvcpItf     = nullptr;
+    std::shared_ptr<mhw::vdbox::aqm::Itf>    m_aqmItf      = nullptr;
     // States
     PMOS_INTERFACE       m_osInterface;  //!< Pointer to OS interface
 
