@@ -32,6 +32,11 @@
 #include "mhw_state_heap.h"
 #include "mhw_mmio_common.h"
 
+#ifdef _MEDIA_RESERVED
+#define __MHW_MI_WRAPPER_EXT(STUFF) STUFF
+#else
+#define __MHW_MI_WRAPPER_EXT(STUFF)
+#endif
 namespace mhw
 {
 namespace mi
@@ -401,6 +406,8 @@ namespace mi
 
 #ifdef _MEDIA_RESERVED
 #include "mhw_mi_cmdpar_ext.h"
+#else
+#define INIT_MHW_MI_SEMAPHORE_WAIT_64_PARAMS(params, semaMem, semaData, opCode, semaMemOffset)
 #endif
 
 #endif  // __MHW_MI_CMDPAR_H__
