@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2022, Intel Corporation
+* Copyright (c) 2022-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -29,15 +29,7 @@
 #define __MHW_SFC_CMDPAR_H__
 
 #include "mhw_sfc.h"
-
-#ifdef IGFX_SFC_INTERFACE_EXT_SUPPORT
-#include "mhw_sfc_cmdpar_ext.h"
-#define __MHW_SFC_WRAPPER(STUFF)
-#define __MHW_SFC_WRAPPER_EXT(STUFF) STUFF
-#else
-#define __MHW_SFC_WRAPPER(STUFF) STUFF
-#define __MHW_SFC_WRAPPER_EXT(STUFF)
-#endif
+#include "mhw_cmdpar.h"
 
 namespace mhw
 {
@@ -45,6 +37,10 @@ namespace sfc
 {
 static constexpr uint32_t MHW_SFC_MAX_WIDTH    = 16 * 1024;
 static constexpr uint32_t MHW_SFC_MAX_HEIGHT   = 16 * 1024;
+
+static constexpr uint32_t MHW_SFC_OUTPUT_MIN_WIDTH  = 32;
+static constexpr uint32_t MHW_SFC_OUTPUT_MIN_HEIGHT = 32;
+
 static constexpr uint32_t MHW_SFC_MAX_PIPE_NUM = 4;
 
 enum MHW_SFC_INDEX
@@ -145,7 +141,7 @@ struct _MHW_PAR_T(SFC_STATE)
     bool bCSCEnable                             = false;  // YUV->RGB/YUV->YUV CSC enable
     bool bRGBASwapEnable                        = false;  // R, B Channel Swap enable
     bool bInputColorSpace                       = false;  //0: YUV color space, 1:RGB color space
-
+    bool isFullRgbG10P709                       = false;  // Whether output colorspace is COLOR_SPACE_RGB_FULL_G10_NONE_P709
     // Memory compression Enable Flag
     bool bMMCEnable                             = false;            // Flag used to decide whether sfc output should be compressed
     MOS_RESOURCE_MMC_MODE MMCMode               = MOS_MMC_DISABLED; // Memory compression mode
@@ -192,10 +188,14 @@ struct _MHW_PAR_T(SFC_STATE)
     uint32_t      bottomFieldVerticalScalingOffset = 0;  // Bottom field vertical scaling offset
     PMOS_RESOURCE tempFieldResource = nullptr;           // Temp filed surface
 
+    PMOS_RESOURCE sfcIndirectState  = nullptr;
+
     PMOS_RESOURCE pOsResAVSLineBufferSplit[MHW_SFC_MAX_PIPE_NUM] = {};  //!< AVS Line buffer used by SFC
     PMOS_RESOURCE pOsResIEFLineBufferSplit[MHW_SFC_MAX_PIPE_NUM] = {};  //!< IEF Line buffer used by SFC
     PMHW_SFC_OUT_SURFACE_PARAMS             pOutSurface = nullptr;
-    __MHW_SFC_WRAPPER_EXT(SFC_STATE_CMDPAR_EXT);
+    uint32_t      av1TileRowNumber                               = 0;
+    uint32_t      av1TileColumnNumber                            = 0;
+    bool          isDemosaicEnabled                              = false;  //!< Enable Demosaic
 };
 
 struct _MHW_PAR_T(SFC_AVS_STATE)
