@@ -1031,7 +1031,7 @@ public:
         return m_veboxScalabilitywith4K;
     }
 
-    MOS_STATUS Add1DLutState(void *&surface, PMHW_1DLUT_PARAMS p1DLutParams) override
+    MOS_STATUS Add1DLutState(void *surface, PMHW_1DLUT_PARAMS p1DLutParams) override
     {
         return MOS_STATUS_SUCCESS;
     }
