@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2022, Intel Corporation
+* Copyright (c) 2019-2025, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -104,26 +104,29 @@ typedef enum
 //       in mos_util_user_feature_keys.h if you change this enum.
 typedef enum
 {
-    MOS_CP_SUBCOMP_DDI              = 0,             // CP-related DDIs
-    MOS_CP_SUBCOMP_DEVICE           = 1,             // The CP device class
-    MOS_CP_SUBCOMP_OS               = 2,             // The CP OS services classes
-    MOS_CP_SUBCOMP_PCH_HAL          = 3,             // The CP PCH HAL class
-    MOS_CP_SUBCOMP_GPU_HAL          = 4,             // The CP GPU HAL classes
-    MOS_CP_SUBCOMP_CODEC            = 5,             // Content Protection portions of the Codec UMD
-    MOS_CP_SUBCOMP_UMD_CONTEXT      = 6,             // Content Protection portions of UMD device context
-    MOS_CP_SUBCOMP_CMD_BUFFER       = 7,             // Content Protection Command buffer class
-    MOS_CP_SUBCOMP_SECURESESSION    = 8,             // The secure session classes
-    MOS_CP_SUBCOMP_AUTHCHANNEL      = 9,             // The AuthChannel classes
-    MOS_CP_SUBCOMP_DLL              = 10,            // CP DLL classes
-    MOS_CP_SUBCOMP_LIB              = 11,            // Lib classes
-    MOS_CP_SUBCOMP_MHW              = 12,            // CP MHW classes
-    MOS_CP_SUBCOMP_PROTECTEDSESSION = 13,            // Protected session class
-    MOS_CP_SUBCOMP_PROTECTED_RESOURCE_SESSION = 14,  // Protected Resource session class
-    MOS_CP_SUBCOMP_TEE_HAL          = 15,            // CP TEE HAL class
-    MOS_CP_SUBCOMP_CAPS             = 16,            // CP CAPS clas
-    MOS_CP_SUBCOMP_CPLIB            = 17,            // CP CPLIB interacting
-    MOS_CP_SUBCOMP_CENC             = 18,            // CP cenc class
-    MOS_CP_SUBCOMP_COUNT                             // Must be last in the list
+    MOS_CP_SUBCOMP_DDI              = 0,                              // CP-related DDIs
+    MOS_CP_SUBCOMP_DEVICE           = MOS_CP_SUBCOMP_DDI,             // (DDI)The CP device class
+    MOS_CP_SUBCOMP_UMD_CONTEXT      = MOS_CP_SUBCOMP_DDI,             // (DDI)Content Protection portions of UMD device context
+    MOS_CP_SUBCOMP_SECURESESSION    = MOS_CP_SUBCOMP_DDI,             // (DDI)The secure session classes
+    MOS_CP_SUBCOMP_AUTHCHANNEL      = MOS_CP_SUBCOMP_DDI,             // (DDI)The AuthChannel classes
+    MOS_CP_SUBCOMP_PROTECTEDSESSION = MOS_CP_SUBCOMP_DDI,             // (DDI)Protected session class
+    MOS_CP_SUBCOMP_PROTECTED_RESOURCE_SESSION = MOS_CP_SUBCOMP_DDI,   // (DDI)Protected Resource session class
+    MOS_CP_SUBCOMP_CAPS             = MOS_CP_SUBCOMP_DDI,             // (DDI)CP CAPS clas
+
+    MOS_CP_SUBCOMP_OS               = 1,                              // The CP OS services classes
+
+    MOS_CP_SUBCOMP_TEE_HAL          = 2,                              // CP TEE HAL class
+    MOS_CP_SUBCOMP_PCH_HAL          = MOS_CP_SUBCOMP_TEE_HAL,         // (TEE_HAL)The CP PCH HAL class
+    MOS_CP_SUBCOMP_DLL              = MOS_CP_SUBCOMP_TEE_HAL,         // (TEE_HAL)CP DLL classes
+
+    MOS_CP_SUBCOMP_GPU_HAL          = 3,                              // The CP GPU HAL classes
+
+    MOS_CP_SUBCOMP_MHW              = 4,                              // CP MHW classes
+
+    MOS_CP_SUBCOMP_CODEC            = 5,                              // Content Protection portions of the Codec UMD
+    MOS_CP_SUBCOMP_CENC             = MOS_CP_SUBCOMP_CODEC,           // (CODEC)CP cenc class
+
+    MOS_CP_SUBCOMP_COUNT                                              // Must be last in the list
 } MOS_CP_SUBCOMP_ID;
 
 //!
@@ -184,12 +187,15 @@ typedef enum
 {
     MOS_MESSAGE_LVL_DISABLED                  = 0,
     MOS_MESSAGE_LVL_CRITICAL                  = 1,
-    MOS_MESSAGE_LVL_NORMAL                    = 2,
-    MOS_MESSAGE_LVL_VERBOSE                   = 3,
-    MOS_MESSAGE_LVL_FUNCTION_ENTRY            = 4,
-    MOS_MESSAGE_LVL_FUNCTION_EXIT             = 5,
-    MOS_MESSAGE_LVL_FUNCTION_ENTRY_VERBOSE    = 6,
-    MOS_MESSAGE_LVL_MEMNINJA                  = 7,
+    // Add warning level, which is defined in 4th bit separately, keep the 3-bit message level and 1-bit assert flag setting unchanged.
+    MOS_MESSAGE_LVL_WARNING                   = 2,
+    // Map the legacy message level (>= MOS_MESSAGE_LVL_NORMAL) to level+1, keep the 3-bit message level and 1-bit assert flag setting unchanged.
+    MOS_MESSAGE_LVL_NORMAL                    = 3,
+    MOS_MESSAGE_LVL_VERBOSE                   = 4,
+    MOS_MESSAGE_LVL_FUNCTION_ENTRY            = 5,
+    MOS_MESSAGE_LVL_FUNCTION_EXIT             = 6,
+    MOS_MESSAGE_LVL_FUNCTION_ENTRY_VERBOSE    = 7,
+    MOS_MESSAGE_LVL_MEMNINJA                  = 8,
     MOS_MESSAGE_LVL_COUNT
 } MOS_MESSAGE_LEVEL;
 
@@ -658,6 +664,13 @@ MEDIA_CLASS_DEFINE_END(MosUtilDebug)
     MOS_CRITICALMESSAGE(_compID, _subCompID, _message, ##__VA_ARGS__);                      \
     MOS_ASSERT(_compID, _subCompID, false);
 
+//!
+//! \def MOS_WARNINGMESSAGE(_compID, _subCompID, _message, ...)
+//!  Output DEBUG message \a _message with \_a _compID and \_a _subCompID info
+//!
+#define MOS_WARNINGMESSAGE(_compID, _subCompID, _message, ...)                              \
+    MOS_DEBUGMESSAGE(MOS_MESSAGE_LVL_WARNING, _compID, _subCompID, _message, ##__VA_ARGS__)
+
 //!
 //! \def MOS_NORMALMESSAGE(_compID, _subCompID, _message, ...)
 //!  Output NORMAL message \a _message with \_a _compID and \_a _subCompID info
@@ -886,6 +899,7 @@ MEDIA_CLASS_DEFINE_END(MosUtilDebug)
 #define MOS_FUNCTION_EXIT(_compID, _subCompID, hr)
 #define MOS_FUNCTION_ENTER_VERBOSE(_compID, _subCompID)
 #define MOS_ASSERTMESSAGE(_compID, _subCompID, _message, ...)
+#define MOS_WARNINGMESSAGE(_compID, _subCompID, _message, ...)
 #define MOS_NORMALMESSAGE(_compID, _subCompID, _message, ...)
 #define MOS_VERBOSEMESSAGE(_compID, _subCompID, _message, ...)
 #define MOS_CRITICALMESSAGE(_compID, _subCompID, _message, ...)
@@ -1355,6 +1369,13 @@ MOS_CHK_NULL_RETURN_NULL(MOS_COMPONENT_OS, MOS_SUBCOMP_SELF, _ptr)
 #define MOS_OS_CRITICALMESSAGE(_message, ...)                                                 \
     MOS_CRITICALMESSAGE(MOS_COMPONENT_OS, MOS_SUBCOMP_SELF, _message, ##__VA_ARGS__)
 
+//!
+//! \def MOS_OS_WARNINGMESSAGE(_message, ...)
+//!  MOS_UTIL_WARNINGMESSAGE \a _message with MOS Utility comp/subcomp info
+//!
+#define MOS_OS_WARNINGMESSAGE(_message, ...)                                                \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_OS, MOS_SUBCOMP_SELF, _message, ##__VA_ARGS__)
+
 //!
 //! \def MOS_OS_NORMALMESSAGE(_message, ...)
 //!  MOS_UTIL_NORMALMESSAGE \a _message with MOS Utility comp/subcomp info
