@@ -32,7 +32,8 @@
 #include <va/va_backend.h>
 #include <semaphore.h>
 #include "GmmLib.h"
-#include "mos_bufmgr.h"
+#include "mos_bufmgr_api.h"
+#include "mos_defs_specific.h"
 
 #define DDI_MEDIA_MAX_SURFACE_NUMBER_CONTEXT       127
 #define DDI_MEDIA_MAX_INSTANCE_NUMBER              0x0FFFFFFF
@@ -79,6 +80,7 @@
 #define DDI_CODEC_VDENC_MAX_L1_REF_FRAMES_LDB      3
 #define DDI_CODEC_VDENC_MAX_L0_REF_FRAMES          3
 #define DDI_CODEC_VDENC_MAX_L1_REF_FRAMES          0
+#define DDI_CODEC_VDENC_MAX_L1_REF_FRAMES_RAB_AVC  1
 
 #define DDI_CODEC_FEI_MAX_NUM_MVPREDICTOR     4
 typedef pthread_mutex_t  MEDIA_MUTEX_T, *PMEDIA_MUTEX_T;
@@ -171,7 +173,7 @@ typedef struct _DDI_MEDIA_SURFACE_DESCRIPTOR
     bool       bIsGralloc;                            // buffer allocated by Gralloc
     void      *pPrivateData;                          // brief reserved for passing private data
     GMM_RESCREATE_PARAMS GmmParam;                    // GMM Params for Gralloc buffer
-    uint64_t   modifier;                              // used for VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME_2
+    uint64_t   modifier;                              // used for VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME_2 or VA_SURFACE_ATTRIB_MEM_TYPE_DRM_PRIME_3
 } DDI_MEDIA_SURFACE_DESCRIPTOR,*PDDI_MEDIA_SURFACE_DESCRIPTOR;
 
 typedef union _DDI_MEDIA_SURFACE_STATUS_REPORT
@@ -342,23 +344,8 @@ typedef struct _DDI_X11_FUNC_TABLE
 }DDI_X11_FUNC_TABLE, *PDDI_X11_FUNC_TABLE;
 #endif
 
-#ifdef MEDIA_SOFTLET
-
-#include "media_interfaces_hwinfo.h"
-class MediaLibvaCapsNext;
-class OsContext;
-class GpuContextMgr;
-#include "ddi_media_functions.h"
-#include "ddi_media_context.h"
-
-typedef struct DDI_MEDIA_CONTEXT *PDDI_MEDIA_CONTEXT;
-
-#else // MEDIA_SOFTLET
-
 #include "media_libva_common.h"
 
-#endif // MEDIA_SOFTLET
-
 static __inline PDDI_MEDIA_CONTEXT GetMediaContext (VADriverContextP ctx)
 {
     return (PDDI_MEDIA_CONTEXT)ctx->pDriverData;
